import React, { Component, PropTypes } from 'react';


class InputText extends Component {

  constructor(props) {
    super(props);

    this.state = { value: '' };

    this.handleChange = this.handleChange.bind(this);
  }

  componentWillMount() {
    if (this.props.value) {
      this.setState({ value: this.props.value });
    }
  }

  renderLabel() {
    return this.props.label ? <label>{this.props.label}</label> : null;
  }

  renderErrors() {
    if (! this.props.errors) return null;

    return (
      <p>{this.props.errors.map((msg, i) => (<span key={i}>{msg}</span>))}</p>
    )
  }

  render() {
    return (
      <div className="form-group">
        {this.renderLabel()}
        <input type="text"
               className="form-control"
               ref="input"
               name={this.props.name}
               value={this.state.value}
               onChange={this.handleChange} />
        {this.renderErrors()}
      </div>
    );
  }

  handleChange() {
    const value = this.refs.input.value;
    this.setState({ value });

    if (this.props.onChange) {
      const feedback = this.props.onChange(value);
      this.setState({ feedbackState: feedback });
    }
  }
}

InputText.propTypes = {
  label: PropTypes.string,
  name: PropTypes.string.isRequired,
  value: PropTypes.string
};

export default InputText;